@@ -41,20 +41,6 @@ class Service(Generic[ModelT]):
     def __init__(self, **repo_kwargs: Any) -> None:
         self.repository: AbstractRepository[ModelT] = self.repository_type(**repo_kwargs)
 
-    # noinspection PyMethodMayBeStatic
-    async def authorize_create(self, data: ModelT) -> ModelT:
-        """Control resource creation.
-
-        Can use `self.user` here.
-
-        Args:
-            data: The object to be created.
-
-        Returns:
-            The object with restricted attribute values removed.
-        """
-        return data
-
     async def create(self, data: ModelT) -> ModelT:
         """Wraps repository instance creation.
 
@@ -64,13 +50,8 @@ class Service(Generic[ModelT]):
         Returns:
             Representation of created instance.
         """
-        data = await self.authorize_create(data)
         return await self.repository.add(data)
 
-    # noinspection PyMethodMayBeStatic
-    async def authorize_list(self) -> None:
-        """Authorize collection access."""
-
     async def list(self, *filters: "FilterTypes", **kwargs: Any) -> list[ModelT]:
         """Wraps repository scalars operation.
 
@@ -81,22 +62,8 @@ class Service(Generic[ModelT]):
         Returns:
             The list of instances retrieved from the repository.
         """
-        await self.authorize_list()
         return await self.repository.list(*filters, **kwargs)
 
-    async def authorize_update(self, id_: Any, data: ModelT) -> ModelT:
-        """Authorize update of item.
-
-        Args:
-            id_: Identifier of the object to be updated.
-            data: The object to be updated.
-
-        Returns:
-            ModelT
-        """
-        self.repository.set_id_attribute_value(id_, data)
-        return data
-
     async def update(self, id_: Any, data: ModelT) -> ModelT:
         """Wraps repository update operation.
 
@@ -107,21 +74,8 @@ class Service(Generic[ModelT]):
         Returns:
             Updated representation.
         """
-        data = await self.authorize_update(id_, data)
-        return await self.repository.update(data)
-
-    async def authorize_upsert(self, id_: Any, data: ModelT) -> ModelT:
-        """Authorize upsert of item.
-
-        Args:
-            id_: The identifier of the resource to upsert.
-            data: The object to be updated.
-
-        Returns:
-            ModelT
-        """
         self.repository.set_id_attribute_value(id_, data)
-        return data
+        return await self.repository.update(data)
 
     async def upsert(self, id_: Any, data: ModelT) -> ModelT:
         """Wraps repository upsert operation.
@@ -133,16 +87,9 @@ class Service(Generic[ModelT]):
         Returns:
             Updated or created representation.
         """
-        data = await self.authorize_upsert(id_, data)
+        self.repository.set_id_attribute_value(id_, data)
         return await self.repository.upsert(data)
 
-    async def authorize_get(self, id_: Any) -> None:
-        """Authorize get of item.
-
-        Args:
-            id_: Identifier of item to be retrieved.
-        """
-
     async def get(self, id_: Any) -> ModelT:
         """Wraps repository scalar operation.
 
@@ -152,16 +99,8 @@ class Service(Generic[ModelT]):
         Returns:
             Representation of instance with identifier `id_`.
         """
-        await self.authorize_get(id_)
         return await self.repository.get(id_)
 
-    async def authorize_delete(self, id_: Any) -> None:
-        """Authorize delete of item.
-
-        Args:
-            id_: Identifier of item to be retrieved.
-        """
-
     async def delete(self, id_: Any) -> ModelT:
         """Wraps repository delete operation.
 
@@ -171,7 +110,6 @@ class Service(Generic[ModelT]):
         Returns:
             Representation of the deleted instance.
         """
-        await self.authorize_delete(id_)
         return await self.repository.delete(id_)
 
     async def enqueue_background_task(self, method_name: str, **kwargs: Any) -> None:
